@@ -58,7 +58,7 @@ your array data contains C<^G> characters as it is possible that
 two different arrays can be converted to the same string.
 
 To avoid this, it is possible to override the default separator
-character, either by passing and alternative to the C<new> function
+character, either by passing an alternative to the C<new> function
 
   my $comp = Array::Compare->new(Sep => '|');
 
@@ -73,7 +73,7 @@ You can also control whether or not whitespace within the elements of
 the arrays should be considered significant when making the comparison.
 The default is that all whitespace is significant. The alternative is
 for all consecutive white space characters to be converted to a single
-space for the pruposes of the comparison. Again, this can be turned on
+space for the purposes of the comparison. Again, this can be turned on
 when creating a comparator object:
 
   my $comp = Array::Compare->new(WhiteSpace => 0);
@@ -100,7 +100,7 @@ which differ between the two arrays. If the arrays are the same it returns
 an empty list. In scalar context the full comparison returns the length of
 this list (i.e. the number of elements that differ). You can access the full
 comparison in two ways. Firstly, there is a C<DefFull> attribute. If this
-is C<true> then a full comparison if carried out whenever the C<compare>
+is C<true> then a full comparison is carried out whenever the C<compare>
 method is called.
 
   my $comp = Array::Compare->new(DefFull => 1);
@@ -155,10 +155,9 @@ or:
   my %skip = (1 => 1, 2 => 2);
   $comp->Skip(\%skip);
 
-To reset the comparator so that no longer skips elements, set the skip
-hash to an empty hash.
+To reset the comparator so that no longer skips elements, call NoSkip().
 
-  $comp->Skip({});
+  $comp->NoSkip();
 
 You can also check to see if one array is a permutation of another, i.e.
 they contain the same elements but in a different order.
@@ -178,7 +177,7 @@ but C<Skip> is ignored for, hopefully, obvious reasons.
 
 package Array::Compare;
 
-require 5.006_000;
+require 5.010_000;
 use strict;
 use warnings;
 our ($VERSION, $AUTOLOAD);
@@ -187,7 +186,7 @@ use Moo;
 use Types::Standard qw(Str Bool HashRef);
 use Carp;
 
-$VERSION = '3.0.1';
+$VERSION = '3.0.3';
 
 has Sep        => ( is => 'rw', isa => Str,     default => '^G' );
 has WhiteSpace => ( is => 'rw', isa => Bool,    default => 1 );
@@ -228,6 +227,18 @@ a reference to a hash which contains the numbers of any columns that should
 be skipped in the comparison. Default is an empty hash (all columns are
 significant).
 
+=item NoSkip
+
+Reset skipped column details. It assigns {} to the attribute C<Skip>.
+
+=cut
+
+sub NoSkip {
+    my $self = shift;
+
+    $self->Skip({});
+}
+
 =item DefFull
 
 Flag which indicates whether the default comparison is simple (just returns
@@ -246,9 +257,14 @@ comparison).
 #
 sub _check_args {
   my $self = shift;
-  croak('Must compare two arrays.') unless @_ == 2;
-  croak('Argument 1 is not an array') unless ref($_[0]) eq 'ARRAY';
-  croak('Argument 2 is not an array') unless ref($_[1]) eq 'ARRAY';
+
+  my @errs;
+
+  push @errs, 'Must compare two arrays.' unless @_ == 2;
+  push @errs, 'Argument 1 is not an array' unless ref($_[0]) eq 'ARRAY';
+  push @errs, 'Argument 2 is not an array' unless ref($_[1]) eq 'ARRAY';
+
+  croak join "\n", @errs if @errs;
 
   return;
 }
@@ -268,6 +284,19 @@ sub compare_len {
   return @{$_[0]} == @{$_[1]};
 }
 
+=head2 different_len \@ARR1, \@ARR2
+
+Passed two arrays and returns true if they are of different lengths.
+
+This is just the inverse of C<compare_len> (which is badly named).
+
+=cut
+
+sub different_len {
+  my $self = shift;
+  return ! $self->compare_len(@_);
+}
+
 =head2 compare \@ARR1, \@ARR2
 
 Compare the values in two arrays and return a data indicating whether
@@ -356,7 +385,7 @@ Do a full comparison between two arrays.
 
 Checks each individual column. In scalar context returns the number
 of columns that differ (zero if the arrays are the same). In list
-context returns an list containing the indexes of the columns that
+context returns a list containing the indexes of the columns that
 differ (an empty list if the arrays are the same).
 
 Uses the values of 'Sep' and 'WhiteSpace' to influence the comparison.
@@ -384,18 +413,8 @@ sub full_compare {
   # the number of the columns that appear in the longer list and aren't
   # in the shorter list. If we've been called in scalar context we
   # return the difference in the lengths of the two lists.
-  unless ($self->compare_len(@_)) {
-    if (wantarray) {
-      my ($max, $min);
-      if ($#{$row1} > $#{$row2}) {
-        ($max, $min) = ($#{$row1}, $#{$row2} + 1);
-      } else {
-        ($max, $min) = ($#{$row2}, $#{$row1} + 1);
-      }
-      return ($min .. $max);
-    } else {
-      return abs(@{$row1} - @{$row2});
-    }
+  if ($self->different_len(@_)) {
+    return $self->_different_len_returns(@_);
   }
 
   my ($arr1, $arr2) = @_;
@@ -407,11 +426,8 @@ sub full_compare {
 
     my ($val1, $val2) = ($arr1->[$_], $arr2->[$_]);
 
-    next unless defined $val1 or defined $val2;
-
-    if ((defined $val1 and not defined $val2)
-      or (defined $val2 and not defined $val1)) {
-      push @diffs, $_;
+    if (not defined $val1 or not defined $val2) {
+      push @diffs, $_ if $self->_defined_diff($val1, $val2);
       next;
     }
 
@@ -431,6 +447,30 @@ sub full_compare {
   return wantarray ? @diffs : scalar @diffs;
 }
 
+sub _different_len_returns {
+  my $self = shift;
+  my ($row1, $row2) = @_;
+
+  if (wantarray) {
+    if ($#{$row1} > $#{$row2}) {
+      return ( $#{$row2} + 1 .. $#{$row1} );
+    } else {
+      return ( $#{$row1} + 1 .. $#{$row2} );
+    }
+  } else {
+    return abs(@{$row1} - @{$row2});
+  }
+}
+
+sub _defined_diff {
+  my $self = shift;
+  my ($val1, $val2) = @_;
+
+  return   if not defined $val1 and not defined $val2;
+  return 1 if     defined $val1 and not defined $val2;
+  return 1 if not defined $val1 and     defined $val2;
+}
+
 =head2 perm \@ARR1, \@ARR2
 
 Check to see if one array is a permutation of the other (i.e. contains
